@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-from featureimpact import FeatureImpact, get_averaged_impact
+from featureimpact import FeatureImpact, make_averaged_impact
 from sklearn import datasets
 from sklearn.preprocessing import StandardScaler
 from sklearn.utils import shuffle
@@ -31,7 +31,7 @@ featimp.make_quantiles(X_train)
 impact = featimp.compute_impact(model, X_test)
 
 # Comparing averaged impact to LinReg's coefficients
-ave_imp = get_averaged_impact(impact, normalize=True)
+ave_imp = make_averaged_impact(impact, normalize=True)
 for i, imp in enumerate(ave_imp):
     print i, imp, coefs[i]
 
